package com.shiro.demo.controller;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.session.Session;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import com.shiro.demo.po.User;
import com.shiro.demo.util.CryptographyUtil;

@Controller
public class UserController {
	private static Logger logger = Logger.getLogger(UserController.class);
	
	@RequestMapping(value="/login",method=RequestMethod.POST)
	public String userLogin(User user , HttpServletRequest req){
		Subject currentUser = SecurityUtils.getSubject();
		String md5Pwd = CryptographyUtil.md5(user.getPassword(), user.getUserName());
		UsernamePasswordToken token = new UsernamePasswordToken(user.getUserName(), md5Pwd);
		try {
			currentUser.login(token);
			logger.info("登录成功");
			Session session = currentUser.getSession();
			logger.info("sessionId:"+session.getId());
			logger.info("sessionHost:"+session.getHost());
			logger.info("sessionTimeOut:"+session.getTimeout());
			return "redirect:/success";
		} catch (AuthenticationException e) {
			req.setAttribute("msg", "用户名或者密码错误");
			e.printStackTrace();
			logger.error("登录失败");
		}
		return "login";
	}
	
	@RequestMapping(value="/login",method=RequestMethod.GET)
	public String login(){
		return "login";
	}
	@RequestMapping(value="/success",method=RequestMethod.GET)
	public String success(){
		return "success";
	}
	@RequestMapping(value="/unauthorized",method=RequestMethod.GET)
	public String unauthorized(){
		return "unauthorized";
	}
	
	@RequestMapping(value="/admin",method=RequestMethod.GET)
	public String admin(){
		return "admin";
	}
	
	@RequestMapping(value="/adminUpdate",method=RequestMethod.GET)
	public String adminUpdate(){
		return "adminUpdate";
	}
	
	@RequestMapping(value="/teacher",method=RequestMethod.GET)
	public String teacher(){
		return "teacher";
	}
	
	@RequestMapping(value="/teacherUpdate",method=RequestMethod.GET)
	public String teacherUpdate(){
		return "teacherUpdate";
	}
	
	
	@RequestMapping(value="/student",method=RequestMethod.GET)
	public String student(){
		return "student";
	}
	
	@RequestMapping(value="/studentUpdate",method=RequestMethod.GET)
	public String studentUpdate(){
		return "studentUpdate";
	}

	@RequestMapping(value="/logout",method=RequestMethod.GET)
	public String logout(){
		Subject currentUser = SecurityUtils.getSubject();
		currentUser.logout();
		return "login";
	}
	
	
}
