package com.shiro.demo.realm;

import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.AuthenticationInfo;
import org.apache.shiro.authc.AuthenticationToken;
import org.apache.shiro.authc.SimpleAuthenticationInfo;
import org.apache.shiro.authz.AuthorizationInfo;
import org.apache.shiro.authz.SimpleAuthorizationInfo;
import org.apache.shiro.realm.AuthorizingRealm;
import org.apache.shiro.subject.PrincipalCollection;
import org.springframework.beans.factory.annotation.Autowired;

import com.shiro.demo.po.User;
import com.shiro.demo.service.api.UserServiceApi;


public class MyRealm extends AuthorizingRealm{
	
	@Autowired
	private UserServiceApi api;
	
	/**
	 * 为当前登录成功的用户授予角色和权限
	 */
	protected AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principals) {
		String userName = (String)principals.getPrimaryPrincipal();
		SimpleAuthorizationInfo authorizationInfo = new SimpleAuthorizationInfo();
		try {
			authorizationInfo.setRoles(api.getRoleByUserName(userName));
			authorizationInfo.setStringPermissions(api.getPermissionByUserName(userName));
			return authorizationInfo;
		} catch (Exception e) {
			e.printStackTrace();
		}
		return null;
		
	}

	/**
	 * 验证当前登录的用户
	 */
	protected AuthenticationInfo doGetAuthenticationInfo(AuthenticationToken token) throws AuthenticationException {
		try {
			String userName = (String)token.getPrincipal();
			
			User resultUser = api.getUserByName(userName);
			
			if(resultUser != null){
				AuthenticationInfo authcInfo = new SimpleAuthenticationInfo(resultUser.getUserName(),resultUser.getPassword(),"xx");
				return authcInfo;
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		
		
		return null;
	}

}
